@@ -1,5 +1,5 @@
-#ifndef __CONSTANTS_H
-#define __CONSTANTS_H
+#ifndef CLDAQ__CONSTANTS_H
+#define CLDAQ__CONSTANTS_H
 
 static const Tint len = 24;
 Tint nevent[len] =
