@@ -1,7 +1,15 @@
 // =====================================================================
-//  $Id: TRunManager.cc,v 1.17 2004/09/01 08:08:36 goiwai Exp $
-//  $Name: CLDAQ-1-14-05 $
+//  $Id: TRunManager.cc,v 1.19 2006/02/15 05:41:59 goiwai Exp $
+//  $Name: CLDAQ-1-14-06 $
 //  $Log: TRunManager.cc,v $
+//  Revision 1.19  2006/02/15 05:41:59  goiwai
+//  äνäȴְäƤΤǺٽޤ
+//
+//  Revision 1.18  2006/02/15 05:38:18  goiwai
+//  Suspend()ƤФʤХν
+//  thread_join()ΤSuspendRun()¹Ԥ롣
+//  EventLoopǤʤIdleˤʤΤ᤿
+//
 //  Revision 1.17  2004/09/01 08:08:36  goiwai
 //  ҥץclose褦ˤ
 //
@@ -537,8 +545,7 @@ Tvoid* TRunManager::doEventLoop( Tvoid* arguments )
     }
 
     if ( runmanager -> GetStatus() == tStatusWaitingReady ) {
-      runmanager -> GetRunTimer().Pause();
-      runmanager -> SetStatus( tStatusIdle );
+      runmanager -> SetStatus( tStatusReady );
       break;
     } else {
       runmanager -> SetStatus( tStatusReady );
@@ -558,6 +565,7 @@ Tvoid TRunManager::WaitReturnFromEventLoop()
 {
   pthread_join( theThreadOfEventLoop, 0 );
   pthread_detach( theThreadOfEventLoop );
+  SuspendRun();
   return;
 }
 
@@ -670,8 +678,8 @@ Tvoid TRunManager::PrintAuthorInformation( Tostream& tos ) const
   //ΤϤ椦ϤäɤɤΤǤ
   //tos << "Project: " << Tproject << Tendl;
   //tos << "Version: " << Tversion << Tendl;
-  //tos << "$Id: TRunManager.cc,v 1.17 2004/09/01 08:08:36 goiwai Exp $" << Tendl;
-  //tos << "$Name: CLDAQ-1-14-05 $" << Tendl;
+  //tos << "$Id: TRunManager.cc,v 1.19 2006/02/15 05:41:59 goiwai Exp $" << Tendl;
+  //tos << "$Name: CLDAQ-1-14-06 $" << Tendl;
   //for ( Tint col = 0; col < ncol; col ++ ) {
   //tos << "-";
   //}
